toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final context = [
    if (format != null) 'format: $format',
    if (offset != null) 'offset: $offset',
    if (entryPath != null) 'entry: $entryPath',
  ];
  final suffix = context.isEmpty ? '' : ' (${context.join(', ')})';
  // Note: runtimeType may be minified in dart2js production builds; the
  // message itself is always descriptive.
  return '$runtimeType: $message$suffix';
}