EncryptedArchiveException class

The archive (or the requested entry) is encrypted and no password was supplied, or it uses an encryption scheme this implementation does not support (doc/encryption-scope.md, e.g. ZIP strong encryption, RAR4 encrypted headers).

Inheritance

Constructors

EncryptedArchiveException(String message, {String? format, int? offset, String? entryPath})
Creates an EncryptedArchiveException.

Properties

entryPath String?
Normalized path of the entry the problem relates to, when applicable.
finalinherited
format String?
Name of the archive format being parsed (e.g. zip), when known.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the problem.
finalinherited
offset int?
Byte offset into the archive where the problem was detected, when known.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited